/*! \file utils.h
 *  \brief Declare some \ref Date utility functions.
 */

#ifndef UTILS_H
#define UTILS_H

#include "date.h"

/*! 
 * \fn bool before(const Date &d1, const Date &d2)
 * \brief This utility function compares two \ref Date objects.
 * \param d1 First \ref Date.
 * \param d2 Second \ref Date.
 * \return Returns <TT>True</TT> if \f$d1<=d2\f$ else <TT>False</TT>.
 * \warning Only works for same year dates.
 * \todo Extend to dates that happens at different years.
 */
bool before(const Date &d1, const Date &d2);

/*! 
 * \fn bool difference(const Date &d1, const Date &d2)
 * \brief This utility function returns the number of days from d1 to d2.
 * \param d1 First \ref Date.
 * \param d2 Second \ref Date.
 * \return Returns \f$d2-d1\f$ in term of days.
 * \warning It is assumed that months are 30 day long.
 * \todo Add support for years
 */
int difference(const Date &d1, const Date &d2);

/*! 
 * \fn bool duration(const Date &d1, const Date &d2)
 * \brief This utility function returns the number of days between d1 and d2.
 * \param d1 First \ref Date.
 * \param d2 Second \ref Date.
 * \return Returns \f$d2-d1\f$ if \f$(d2>d1)\f$ else \f$d1-d2\f$.
 * \todo Add support for years
 */
int duration(const Date &d1, const Date &d2);

#endif /* end of include guard: UTILS_H */
