/*! \file main.cpp
 *  \brief This program computes the day averaged price of a trip.
 *  \author Jean-Baptiste Keck
 *  \version 1.0
 *  \date October 8, 2018
 *
 * This program takes six integers as input:
 *  1. <B>sday</B>: start day
 *  2. <B>smonth</B>: start month
 *  3. <B>syear</B>: start year
 *  4. <B>eday</B>: end day
 *  5. <B>emonth</B>: end month
 *  6. <B>eyear:</B> end year
 *
 *  The program will ask the user for a price to create a \ref Trip object from those data.
 *
 *  It then proceeds to print the day-averaged price of the trip to the screen.
 */

#include <iostream>  /* required by std::cout and std::endl */
#include <cstdlib>   /* required by atoi, EXIT_FAILURE, EXIT_SUCCESS */

#include "trip.h"    /* Trip class definition */

/*!
 * \brief Main function
 * \param argc An integer argument count of the command line arguments
 * \param argv An argument vector of the command line arguments
 * \return An integer: 0 on <TT>EXIT_SUCCESS</TT> or a positive integer on <TT>EXIT_FAILURE</TT>.
 */
int main(int argc, const char *argv[])
{
    if (argc != 7) {
        std::cerr << "Usage " << argv[0] 
                  << " [sday] [smonth] [syear]  [eday] [emonth] [eyear]." 
                  << std::endl;
        return EXIT_FAILURE;
    }
    
    int d[6];
    for (int i=0; i<6; i++) { 
        d[i] = std::atoi(argv[i+1]); 
    }
    
    float price;
    std::cout << "Please specify the price of the trip: ";
    std::cin >> price;
    
    Trip trip(d[0], d[1], d[2],
              d[3], d[4], d[5], price);
    trip.print_trip();
    return EXIT_SUCCESS;
}
